Module levels

Module levels 

Self-contained Level and LevelFilter definitions, mirroring the log crate for use on targets where that crate is not embedded (e.g. BPF).

Enums

Level
An enumeration of the available verbosity levels of a log message, ordered from the most severe (Error) to the least severe (Trace).
LevelFilter
An enumeration of the available log level filters, used to enable or suppress log messages at or below a given Level. Includes an Off variant that disables all logging.