Module prelude

Module prelude 

Convenient re-exports of the most commonly used logging macros, level types and console helpers for glob importing.

Macros

log_debug
Format and log message with Level::Debug
log_error
Format and log message with Level::Error
log_info
Format and log message with Level::Info
log_trace
Format and log message with Level::Trace
log_warn
Format and log message with Level::Warn

Enums

Level
An enum representing the available verbosity levels of the logger.
LevelFilter
An enum representing the available verbosity level filters of the logger.

Functions

set_colors_enabled
Enables or disables ANSI color output produced by style.
set_log_level
Enable filtering of log messages using the LevelFilter
style
Wraps an object for formatting for styling.